public inbox for binutils-cvs@sourceware.org
 help / color / mirror / Atom feed
* [binutils-gdb] libctf: typos
@ 2024-05-17 12:02 Nick Alcock
  0 siblings, 0 replies; only message in thread
From: Nick Alcock @ 2024-05-17 12:02 UTC (permalink / raw)
  To: binutils-cvs

https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=7bc376bb9705cf66eea7b9a39442852b173ba6eb

commit 7bc376bb9705cf66eea7b9a39442852b173ba6eb
Author: Nick Alcock <nick.alcock@oracle.com>
Date:   Fri Apr 26 17:50:20 2024 +0100

    libctf: typos
    
    Some functions were renamed without the comments catching up.
    
    libctf/
            * ctf-open.c (upgrade_types_v1): Fix comment typos.

Diff:
---
 libctf/ctf-open.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/libctf/ctf-open.c b/libctf/ctf-open.c
index 9cbf07626cc..03faf2d886f 100644
--- a/libctf/ctf-open.c
+++ b/libctf/ctf-open.c
@@ -438,7 +438,7 @@ upgrade_types_v1 (ctf_dict_t *fp, ctf_header_t *cth)
   tbuf = (ctf_type_v1_t *) (fp->ctf_buf + cth->cth_typeoff);
   tend = (ctf_type_v1_t *) (fp->ctf_buf + cth->cth_stroff);
 
   /* Much like init_types(), this is a two-pass process.
 
      First, figure out the new type-section size needed.  (It is possible,
      in theory, for it to be less than the old size, but this is very
@@ -636,7 +636,7 @@ upgrade_types_v1 (ctf_dict_t *fp, ctf_header_t *cth)
 
   /* Verify that the entire region was converted.  If not, we are either
      converting too much, or too little (leading to a buffer overrun either here
-     or at read time, in init_types().) */
+     or at read time, in init_static_types().) */
 
   assert ((size_t) t2p - (size_t) fp->ctf_buf == cth->cth_stroff);

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2024-05-17 12:02 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -438,7 +438,7 @@ upgrade_types_v1 (ctf_dict_t *fp, ctf_header_t *cth)
   tend = (ctf_type_v1_t *) (fp->ctf_buf + cth->cth_stroff);
 
-  /* Much like init_types(), this is a two-pass process.
+  /* Much like init_static_types(), this is a two-pass process.
 
      First, figure out the new type-section size needed.  (It is possible,
2024-05-17 12:02 [binutils-gdb] libctf: typos Nick Alcock

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).